Module: Spree

Defined in:
app/controllers/spree/orders_controller.rb,
lib/spree/storefront.rb,
app/models/spree/contact.rb,
lib/spree/storefront/engine.rb,
app/models/spree/color_names.rb,
app/helpers/spree/cart_helper.rb,
app/helpers/spree/page_helper.rb,
app/helpers/spree/fonts_helper.rb,
app/helpers/spree/posts_helper.rb,
app/helpers/spree/theme_helper.rb,
app/helpers/spree/turbo_helper.rb,
app/helpers/spree/orders_helper.rb,
app/helpers/spree/taxons_helper.rb,
app/helpers/spree/filters_helper.rb,
app/helpers/spree/checkout_helper.rb,
app/helpers/spree/products_helper.rb,
app/helpers/spree/wishlist_helper.rb,
app/helpers/spree/analytics_helper.rb,
lib/spree/storefront/configuration.rb,
app/helpers/spree/storefront_helper.rb,
app/controllers/spree/seo_controller.rb,
app/controllers/spree/home_controller.rb,
app/controllers/spree/pages_controller.rb,
app/controllers/spree/posts_controller.rb,
app/controllers/spree/store_controller.rb,
app/helpers/spree/canonical_url_helper.rb,
app/controllers/spree/errors_controller.rb,
app/controllers/spree/search_controller.rb,
app/controllers/spree/taxons_controller.rb,
app/presenters/spree/mega_nav_presenter.rb,
app/helpers/spree/payment_methods_helper.rb,
app/controllers/spree/checkout_controller.rb,
app/controllers/spree/contacts_controller.rb,
app/controllers/spree/password_controller.rb,
app/controllers/spree/policies_controller.rb,
app/controllers/spree/products_controller.rb,
app/controllers/spree/settings_controller.rb,
app/controllers/concerns/spree/locale_urls.rb,
app/controllers/spree/addresses_controller.rb,
app/controllers/spree/wishlists_controller.rb,
app/helpers/spree/storefront_locale_helper.rb,
app/controllers/concerns/spree/cart_methods.rb,
app/controllers/spree/line_items_controller.rb,
app/controllers/spree/taxonomies_controller.rb,
app/finders/spree/storefront/variant_finder.rb,
app/helpers/spree/checkout_analytics_helper.rb,
app/controllers/concerns/spree/theme_concern.rb,
app/controllers/spree/account/base_controller.rb,
app/controllers/spree/order_status_controller.rb,
app/helpers/spree/turbo_stream_actions_helper.rb,
app/controllers/spree/digital_links_controller.rb,
app/controllers/spree/page_sections_controller.rb,
app/controllers/spree/account/orders_controller.rb,
app/presenters/spree/featured_product_presenter.rb,
lib/spree/storefront/testing_support/cart_utils.rb,
app/controllers/spree/account/profile_controller.rb,
app/controllers/concerns/spree/password_protected.rb,
app/controllers/spree/account/addresses_controller.rb,
app/controllers/spree/account/gift_cards_controller.rb,
app/controllers/spree/account/newsletter_controller.rb,
lib/spree/storefront/testing_support/capybara_utils.rb,
app/presenters/spree/colors_preview_styles_presenter.rb,
app/controllers/spree/account/wished_items_controller.rb,
lib/generators/spree/storefront/theme/theme_generator.rb,
app/controllers/spree/account/store_credits_controller.rb,
app/controllers/spree/newsletter_subscribers_controller.rb,
lib/generators/spree/storefront/devise/devise_generator.rb,
app/controllers/concerns/spree/storefront/devise_concern.rb,
lib/generators/spree/storefront/install/install_generator.rb,
lib/generators/spree/storefront/devise/templates/user_sessions_controller.rb,
lib/generators/spree/storefront/devise/templates/user_passwords_controller.rb,
lib/generators/spree/storefront/devise/templates/user_registrations_controller.rb

Overview

This concern is used to include the necessary methods and helpers for the Devise controllers It is used to avoid repeating the same code in each controller

Defined Under Namespace

Modules: Account, AnalyticsHelper, CanonicalUrlHelper, CartHelper, CartMethods, CheckoutAnalyticsHelper, CheckoutHelper, FiltersHelper, FontsHelper, LocaleUrls, OrdersHelper, PageHelper, PasswordProtected, PaymentMethodsHelper, PostsHelper, ProductsHelper, Storefront, StorefrontHelper, StorefrontLocaleHelper, TaxonsHelper, ThemeConcern, ThemeHelper, TurboHelper, TurboStreamActionsHelper, WishlistHelper Classes: AddressesController, CheckoutController, ColorNames, ColorsPreviewStylesPresenter, Contact, ContactsController, DigitalLinksController, ErrorsController, FeaturedProductPresenter, HomeController, LineItemsController, MegaNavPresenter, NewsletterSubscribersController, OrderStatusController, OrdersController, PageSectionsController, PagesController, PasswordController, PoliciesController, PostsController, ProductsController, SearchController, SeoController, SettingsController, StoreController, StorefrontConfig, TaxonomiesController, TaxonsController, UserPasswordsController, UserRegistrationsController, UserSessionsController, WishlistsController

Class Method Summary collapse

Class Method Details

.storefrontObject



17
18
19
# File 'lib/spree/storefront.rb', line 17

def self.storefront
  @storefront ||= StorefrontConfig.new
end